summaryrefslogtreecommitdiffstats
path: root/core/src/background.rs
diff options
context:
space:
mode:
Diffstat (limited to 'core/src/background.rs')
-rw-r--r--core/src/background.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/core/src/background.rs b/core/src/background.rs
index 2e28e560..eb4b5021 100644
--- a/core/src/background.rs
+++ b/core/src/background.rs
@@ -12,13 +12,13 @@ pub enum Background {
}
impl Background {
- /// Increases the translucency of the [`Background`]
- /// by the given factor.
- pub fn transparentize(self, factor: f32) -> Self {
+ /// Scales the the alpha channel of the [`Background`] by the given
+ /// factor.
+ pub fn scale_alpha(self, factor: f32) -> Self {
match self {
- Self::Color(color) => Self::Color(color.transparentize(factor)),
+ Self::Color(color) => Self::Color(color.scale_alpha(factor)),
Self::Gradient(gradient) => {
- Self::Gradient(gradient.transparentize(factor))
+ Self::Gradient(gradient.scale_alpha(factor))
}
}
}